==> leptonlib_1.76.0.orig.tar.gz: leptonica-1.76.0/prog/reducetest.c <==
/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -
 -  Redistribution and use in source and binary forms, with or without
 -  modification, are permitted provided that the following conditions
 -  are met:
 -  1. Redistributions of source code must retain the above copyright
 -     notice, this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above
 -     copyright notice, this list of conditions and the following
 -     disclaimer in the documentation and/or other materials
 -     provided with the distribution.
 -
 -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
 -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *====================================================================*/

/*
 * reducetest.c
 *
 *    Carries out a rank binary cascade of up to four 2x reductions.
 *    This requires all four rank levels to be input; to stop the
 *    cascade, use 0 for the final rank level(s).
 */

#include "allheaders.h"

int main(int    argc,
         char **argv)
{
PIX         *pixs, *pixd;
l_int32      level1, level2, level3, level4;
char        *filein, *fileout;
static char  mainName[] = "reducetest";

    if (argc != 7)
        return ERROR_INT(" Syntax:  reducetest filein fileout l1 l2 l3 l4",
                         mainName, 1);
    filein = argv[1];
    fileout = argv[2];
    level1 = atoi(argv[3]);
    level2 = atoi(argv[4]);
    level3 = atoi(argv[5]);
    level4 = atoi(argv[6]);
    setLeptDebugOK(1);

    if ((pixs = pixRead(filein)) == NULL)
        return ERROR_INT("pixs not made", mainName, 1);

#if 1
    pixd = pixReduceRankBinaryCascade(pixs, level1, level2, level3, level4);
#endif

#if 0
    pixd = pixReduce2(pixs, NULL);
#endif

    pixWrite(fileout, pixd, IFF_PNG);

    return 0;
}

==> leptonlib_1.86.0.orig.tar.gz: leptonica-1.86.0/prog/reducetest.c <==
/*====================================================================*
 -  Copyright (C) 2001 Leptonica.  All rights reserved.
 -
 -  Redistribution and use in source and binary forms, with or without
 -  modification, are permitted provided that the following conditions
 -  are met:
 -  1. Redistributions of source code must retain the above copyright
 -     notice, this list of conditions and the following disclaimer.
 -  2. Redistributions in binary form must reproduce the above
 -     copyright notice, this list of conditions and the following
 -     disclaimer in the documentation and/or other materials
 -     provided with the distribution.
 -
 -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
 -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *====================================================================*/

/*
 * reducetest.c
 *
 *    Carries out a rank binary cascade of up to four 2x reductions.
 *    This requires all four rank levels to be input; to stop the
 *    cascade, use 0 for the final rank level(s).
 */

#ifdef HAVE_CONFIG_H
#include <config_auto.h>
#endif  /* HAVE_CONFIG_H */

#include "allheaders.h"

int main(int    argc,
         char **argv)
{
PIX     *pixs, *pixd;
l_int32  level1, level2, level3, level4;
char    *filein, *fileout;

    if (argc != 7)
        return ERROR_INT(" Syntax:  reducetest filein fileout l1 l2 l3 l4",
                         __func__, 1);
    filein = argv[1];
    fileout = argv[2];
    level1 = atoi(argv[3]);
    level2 = atoi(argv[4]);
    level3 = atoi(argv[5]);
    level4 = atoi(argv[6]);
    setLeptDebugOK(1);

    if ((pixs = pixRead(filein)) == NULL)
        return ERROR_INT("pixs not made", __func__, 1);

#if 1
    pixd = pixReduceRankBinaryCascade(pixs, level1, level2, level3, level4);
#endif

#if 0
    pixd = pixReduce2(pixs, NULL);
#endif

    pixWrite(fileout, pixd, IFF_TIFF_G4);
    return 0;
}
